window.Gleam.initSearch([{"doc":"parallel_map","title":"parallel_map","content":"# parallel_map\n\n[![Package Version](https://img.shields.io/hexpm/v/parallel_map)](https://hex.pm/packages/parallel_map)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/parallel_map/)\n\nNote: This package only works for the erlang target.\n\nThis is a simple gleam library that adds a `iterator_pmap` and `list_pmap`,\nwhich has a similar behaviour and interface as `iterator.map` and `list.map`,\nexcept it runs in parallel by spawning extra processes to do the work.\n\n```sh\ngleam add parallel_map\n```\n```gleam\nimport gleam/list\nimport gleam/iterator\nimport gleam/result\nimport parallel_map.{MatchSchedulers, WorkerAmount}\n\npub fn main() {\n  let map_func = fn(a: Int) -&gt; Int {a * a}\n\n  let iterator_input = iterator.range(0, 1000)\n\n  iterator_input\n  |&gt; iterator.map(map_func)\n\n  // can be rewritten as\n  iterator_input\n  |&gt; parallel_map.iterator_pmap(map_func, WorkerAmount(16), 100)\n  |&gt; iterator.map(result.unwrap(_, -1))\n\n  let list_input = list.range(0, 1000)\n\n  list_input\n  |&gt; list.map(map_func)\n\n  // can be rewritten as\n  list_input\n  |&gt; parallel_map.list_pmap(map_func, MatchSchedulersOnline, 100)\n  |&gt; list.map(result.unwrap(_, -1))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/parallel_map&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"parallel_map","title":"WorkerAmount","content":"pub type WorkerAmount {\n  WorkerAmount(value: Int)\n  MatchSchedulersOnline\n}\n This type is used to specify the number of workers to spawn\nWorkerAmount(value: Int)\n will spawn that number of workers\n\nMatchSchedulersOnline\n will spawn workers to match the amount of\n schedulers currently online\n\nSynonyms:\nparallel_map.WorkerAmount\nparallel_map WorkerAmount","url":"parallel_map.html#WorkerAmount"},{"doc":"parallel_map","title":"iterator_pmap","content":"pub fn iterator_pmap(\n  input: Iterator(a),\n  mapping_func: fn(a) -&gt; b,\n  num_workers: WorkerAmount,\n  timeout_milliseconds: Int,\n) -&gt; Iterator(Result(b, Nil))\n This function behaves similarly to gleam_stdlib&#39;s iterator.map\n\n Creates an iterator from an existing iterator and a transformation function\n\n Each element in the new iterator will be the result of calling the given\n function on the elements in the given iterator, with the resulting value\n wrapped in a Result\n\n If the timeout specified is exceeded while attempting\n to collect the result of the computation, the element will instead be Error(Nil)\n\n This function also differs from iterator.map in that it will spawn the workers\n and perform the computation right when it is called,\n but it does not attempt to collect the result until the iterator is later run\nSynonyms:\nparallel_map.iterator_pmap\nparallel_map iterator_pmap","url":"parallel_map.html#iterator_pmap"},{"doc":"parallel_map","title":"list_pmap","content":"pub fn list_pmap(\n  input: List(a),\n  mapping_func: fn(a) -&gt; b,\n  num_workers: WorkerAmount,\n  timeout_milliseconds: Int,\n) -&gt; List(Result(b, Nil))\n This function behaves similarly to gleam_stdlib&#39;s iterator.map\n\n Returns a new list containing only the elements of the first list\n after the function has been applied to each one, with the resulting value\n wrapped in a Result\n\n If the timeout specified is exceeded while attempting\n to collect the result of the computation, the value will instead be Error(Nil)\nSynonyms:\nparallel_map.list_pmap\nparallel_map list_pmap","url":"parallel_map.html#list_pmap"},{"doc":"parallel_map","title":"parallel_map","content":"","url":"parallel_map.html"}]);